@@ -7,10 +7,14 @@
 #ifndef KDEVPLATFORM_ISOURCEFORMATTER_H
 #define KDEVPLATFORM_ISOURCEFORMATTER_H
 
+#include <QMetaType>
 #include <QWidget>
 
 #include "interfacesexport.h"
 
+#include <memory>
+
+class QDebug;
 class QUrl;
 class QMimeType;
 class QStringList;
@@ -29,11 +33,20 @@ public:
 
 	SourceFormatterStyle();
 	explicit SourceFormatterStyle( const QString& name );
+
+	const QString& name() const
+	{
+		return m_name;
+	}
+
 	void setContent( const QString& content );
 	void setCaption( const QString& caption );
 	QString content() const;
-	QString caption() const;
-	QString name() const;
+	const QString& caption() const
+	{
+		return m_caption;
+	}
+
 	QString description() const;
 	void setDescription( const QString& desc );
 	bool usePreview() const;
@@ -55,11 +68,13 @@ public:
 	/// get the language / highlight mode for a given @p mime
 	QString modeForMimetype(const QMimeType& mime) const;
 
-	/// Copy content, mime types and code sample from @p other.
-    void copyDataFrom(SourceFormatterStyle *other);
+	/// Copy everything but name, caption and description from @p other to *this.
+	/// Call this function to set up a new user-defined style based on an existing style.
+	void copyDataFrom(const SourceFormatterStyle& other);
 
 private:
 	bool m_usePreview = false;
+	/// logically const: is modified only in compiler-generated special member functions
 	QString m_name;
 	QString m_caption;
 	QString m_content;
@@ -68,6 +83,14 @@ private:
 	MimeList m_mimeTypes;
 };
 
+inline bool operator==(const SourceFormatterStyle::MimeHighlightPair& a,
+                       const SourceFormatterStyle::MimeHighlightPair& b)
+{
+    return a.mimeType == b.mimeType && a.highlightMode == b.highlightMode;
+}
+
+KDEVPLATFORMINTERFACES_EXPORT QDebug operator<<(QDebug dbg, const SourceFormatterStyle& style);
+
 /**
  * @brief An object describing a style associated with a plugin
  *        which can deal with this style.
@@ -94,26 +117,31 @@ class KDEVPLATFORMINTERFACES_EXPORT SettingsWidget : public QWidget
 		~SettingsWidget() override;
 
 		/** This function is called after the creation of the dialog.
-		* it should initialise the widgets with the values corresponding to
-		* the predefined style \arg name if it's not empty, or
-		* to the string \arg content.
-		*/
-		virtual void load(const SourceFormatterStyle&) = 0;
+		 *
+		 * @param style a custom, not predefined, style to be edited
+		 *
+		 * @note This function must emit previewTextChanged().
+		 */
+		virtual void load(const SourceFormatterStyle& style) = 0;
 
 		/** \return A string representing the state of the config.
 		*/
-		virtual QString save() = 0;
+		virtual QString save() const = 0;
 
 	Q_SIGNALS:
-		/** Emits this signal when a setting was changed and the preview
-		* needs to be updated. \arg text is the text that will be shown in the
-		* editor. One might want to show different text
-		* according to the different pages shown in the widget.
-		* Text should already be formatted.
-		*/
+		/**
+		 * This signal is emitted whenever a setting changes and the preview needs to be updated.
+		 *
+		 * @param text non-empty code sample to be formatted and displayed as style preview
+		 *
+		 * @note The preview text may depend on the current page shown in the widget.
+		 *       So @p text may be different each time this signal is emitted.
+		 */
 		void previewTextChanged(const QString &text);
 };
 
+using SettingsWidgetPtr = std::unique_ptr<SettingsWidget>;
+
 /**
  * @short An interface for a source beautifier
  * An example of a plugin using an external executable to do
@@ -168,9 +196,14 @@ class KDEVPLATFORMINTERFACES_EXPORT ISourceFormatter
 		*/
 		SourceFormatterStyle predefinedStyle(const QString& name) const;
 
+		/**
+		 * @return whether editStyleWidget() returns a valid pointer
+		 */
+		virtual bool hasEditStyleWidget() const = 0;
+
 		/** \return The widget to edit a style.
 		*/
-		virtual SettingsWidget* editStyleWidget(const QMimeType &mime) const = 0;
+		virtual SettingsWidgetPtr editStyleWidget(const QMimeType &mime) const = 0;
 
 		/** \return The text used in the config dialog to preview the current style.
 		*/
@@ -221,6 +254,7 @@ class KDEVPLATFORMINTERFACES_EXPORT ISourceFormatter
 }
 
 Q_DECLARE_INTERFACE(KDevelop::ISourceFormatter, "org.kdevelop.ISourceFormatter")
+Q_DECLARE_METATYPE(KDevelop::SourceFormatterStyle*)
 Q_DECLARE_TYPEINFO(KDevelop::SourceFormatterStyle::MimeHighlightPair, Q_MOVABLE_TYPE);
 Q_DECLARE_TYPEINFO(KDevelop::SourceFormatterStyle, Q_MOVABLE_TYPE);
 Q_DECLARE_TYPEINFO(KDevelop::SourceFormatterStyleItem, Q_MOVABLE_TYPE);
