@@ -58,6 +58,8 @@
 #include <vcs/interfaces/ibasicversioncontrol.h>
 #include <vcs/vcspluginhelper.h>
 
+#include <algorithm>
+
 #define EMPTY_DOCUMENT_URL i18n("Untitled")
 
 using namespace KDevelop;
@@ -144,37 +146,40 @@ public:
 
     }
 
-    void changeDocumentUrl(KDevelop::IDocument* document)
+    void changeDocumentUrl(KDevelop::IDocument* document, const QUrl& previousUrl)
     {
-        QMutableHashIterator<QUrl, IDocument*> it = documents;
-        while (it.hasNext()) {
-            if (it.next().value() == document) {
-                const auto documentIt = documents.constFind(document->url());
-                if (documentIt != documents.constEnd()) {
-                    // Weird situation (saving as a file that is already open)
-                    IDocument* origDoc = *documentIt;
-                    if (origDoc->state() & IDocument::Modified) {
-                        // given that the file has been saved, close the saved file as the other instance will become conflicted on disk
-                        document->close();
-                        controller->activateDocument( origDoc );
-                        break;
-                    }
-                    // Otherwise close the original document
-                    origDoc->close();
-                } else {
-                    // Remove the original document
-                    it.remove();
-                }
+        const auto it = documents.constFind(previousUrl);
+        if (it == documents.cend()) {
+            qCWarning(SHELL) << "a renamed document is not registered:" << document << previousUrl.toString()
+                             << document->url().toString();
+            return;
+        }
+        Q_ASSERT(it.value() == document);
 
-                documents.insert(document->url(), document);
-
-                if (!controller->isEmptyDocumentUrl(document->url()))
-                {
-                    fileOpenRecent->addUrl(document->url());
-                }
-
-                break;
+        const auto documentIt = documents.constFind(document->url());
+        if (documentIt != documents.constEnd()) {
+            // Weird situation (saving as a file that is already open)
+            IDocument* origDoc = *documentIt;
+            Q_ASSERT_X(origDoc != document, Q_FUNC_INFO, "Duplicate documentUrlChanged signal emission?");
+            if (origDoc->state() & IDocument::Modified) {
+                // given that the file has been saved, close the saved file as the other instance will become conflicted on disk
+                document->close(); // this closing erases the iterator `it`
+                controller->activateDocument( origDoc );
+                return;
             }
+            // Otherwise close the original document, but first erase the iterator `it`,
+            // because the closing erases documentIt, which can invalidate `it`.
+            documents.erase(it);
+            origDoc->close();
+        } else {
+            documents.erase(it); // erase the previous-URL entry
+        }
+
+        documents.insert(document->url(), document);
+
+        if (!controller->isEmptyDocumentUrl(document->url()))
+        {
+            fileOpenRecent->addUrl(document->url());
         }
     }
 
@@ -362,14 +367,17 @@ public:
             delete doc;
             return false;
         }
-        //react on document deletion - we need to cleanup controller structures
 
-        QObject::connect(sdoc, &Sublime::Document::aboutToDelete, controller, &DocumentController::notifyDocumentClosed);
         //We check if it was already opened before
-        bool emitOpened = !documents.contains(url);
-        if(emitOpened)
+        const bool wasClosed = !documents.contains(url);
+        if (wasClosed) {
             documents[url]=doc;
 
+            // react on document deletion - we need to clean up controller structures
+            QObject::connect(sdoc, &Sublime::Document::aboutToDelete, controller,
+                             &DocumentController::notifyDocumentClosed);
+        }
+
         if (!activationParams.testFlag(IDocumentController::DoNotCreateView))
         {
             //find a view if there's one already opened in this area
@@ -511,7 +519,7 @@ public:
         }
 
         // Deferred signals, wait until it's all ready first
-        if( emitOpened ) {
+        if (wasClosed) {
             emit controller->documentOpened( doc );
         }
 
@@ -555,8 +563,10 @@ DocumentController::DocumentController( QObject *parent )
     QDBusConnection::sessionBus().registerObject( QStringLiteral("/org/kdevelop/DocumentController"),
         this, QDBusConnection::ExportScriptableSlots );
 
-    connect(this, &DocumentController::documentUrlChanged,
-            this, [this] (IDocument* document) { Q_D(DocumentController); d->changeDocumentUrl(document); });
+    connect(this, &DocumentController::documentUrlChanged, this, [this](IDocument* document, const QUrl& previousUrl) {
+        Q_D(DocumentController);
+        d->changeDocumentUrl(document, previousUrl);
+    });
 
     if(!(Core::self()->setupFlags() & Core::NoUi)) setupActions();
 }
@@ -1180,12 +1190,22 @@ bool DocumentController::openDocumentsWithSplitSeparators( Sublime::AreaIndex* i
                 ret &= openDocumentsWithSplitSeparators( index, group, isFirstView );
             }
         }else{
+            const auto url = QUrl::fromUserInput(urlsWithSeparators.front());
+
+            // The file name of a remote URL that ends with a slash is empty, but such a URL can still reference a file.
+            // The opposite condition is asserted in DocumentControllerPrivate::openDocumentInternal(),
+            // which is (indirectly) called below.
+            if (url.isLocalFile() && url.fileName().isEmpty()) {
+                qCDebug(SHELL) << "cannot open a directory" << url.toString();
+                return false;
+            }
+
             while(index->isSplit())
                 index = index->first();
             // Simply open the document into the area index
-            IDocument* doc = Core::self()->documentControllerInternal()->openDocument(QUrl::fromUserInput(urlsWithSeparators.front()),
-                        KTextEditor::Cursor::invalid(),
-                        IDocumentController::DoNotActivate | IDocumentController::DoNotCreateView);
+            IDocument* doc = Core::self()->documentControllerInternal()->openDocument(
+                url, KTextEditor::Cursor::invalid(),
+                IDocumentController::DoNotActivate | IDocumentController::DoNotCreateView);
             auto *sublimeDoc = dynamic_cast<Sublime::Document*>(doc);
             if (sublimeDoc) {
                 Sublime::View* view = sublimeDoc->createView();
