@@ -339,6 +339,13 @@ QExplicitlySharedDataPointer<IncludePathCompletionContext> executeIncludePathCom
     return QExplicitlySharedDataPointer<IncludePathCompletionContext>{context};
 }
 
+constexpr const char* definesAndIncludesConfigName = "CustomDefinesAndIncludes";
+
+}
+
+void TestCodeCompletion::cleanup()
+{
+    KSharedConfig::openConfig()->deleteGroup(definesAndIncludesConfigName);
 }
 
 void TestCodeCompletion::testClangCodeCompletion()
@@ -638,6 +645,19 @@ void TestCodeCompletion::testReplaceMemberAccess_data()
         QTest::newRow("no replacement in aggregate initializer with floating point number") << code << cis;
     }
 
+    // See https://bugs.kde.org/show_bug.cgi?id=468605
+    {
+        const auto code = QString::fromLatin1(
+            "struct Test { int a; float b; };"
+            "int main(int argc, char **argv) { Test foo{1, \n2.");
+
+        CompletionItems cis;
+        cis.position = {1, 2};
+        cis.completions = QStringList{};
+        cis.code = code;
+        QTest::newRow("no replacement in aggregate initializer with floating point number 2") << code << cis;
+    }
+
     {
         const auto code = QString::fromLatin1(
             "typedef struct myStruct { int x; } myStruct;"
@@ -738,7 +758,7 @@ void TestCodeCompletion::testOverrideExecute()
     QTemporaryDir directory;
     TestProject testProject {Path{directory.path()}};
     auto t = testProject.path().toLocalFile();
-    auto configGroup = testProject.projectConfiguration()->group("CustomDefinesAndIncludes").group("ProjectPath0");
+    auto configGroup = testProject.projectConfiguration()->group(definesAndIncludesConfigName).group("ProjectPath0");
     configGroup.writeEntry("Path", ".");
     configGroup.writeEntry("parserArguments", cppStandard);
     configGroup.sync();
@@ -1670,7 +1690,7 @@ void TestCodeCompletion::testIgnoreGccBuiltins()
     // TODO: make it easier to change the compiler provider for testing purposes
     QTemporaryDir dir;
     auto project = new TestProject(Path(dir.path()), this);
-    auto definesAndIncludesConfig = project->projectConfiguration()->group("CustomDefinesAndIncludes");
+    auto definesAndIncludesConfig = project->projectConfiguration()->group(definesAndIncludesConfigName);
     auto pathConfig = definesAndIncludesConfig.group("ProjectPath0");
     pathConfig.writeEntry("Path", ".");
     pathConfig.group("Compiler").writeEntry("Name", "GCC");
